@@ -34,8 +34,7 @@ class All:
             size = max(size, len(name))
         for name, value in self._all.items():
             name = name.rjust(size)
-            value = capitalize(str(value))
-            result.append(f"{name} | {value}")
+            result.append(f"{name} | {value.count.capitalize}")
         return TransparentString("\n".join(result))
 
 
@@ -70,10 +69,18 @@ class Transform:
         random.shuffle(copy)
         for i in range(n):
             result.append(copy[i])
-        return Items(self._context, result)
+        return Items(
+            _context=self._context,
+            _items=result,
+            _config=self._config,
+        )
 
     def take(self, n):
-        return Items(self._context, self._strings[0:n])
+        return Items(
+            _context=self._context,
+            _config=self._config,
+            _items=self._strings[0:n],
+        )
 
     def set(self, name):
         set_path(self._context, name, self)
@@ -83,19 +90,35 @@ class Transform:
         results = []
         for _ in range(n):
             results.append(random.choice(self._strings))
-        return Items(self._context, results)
+        return Items(
+            _context=self._context,
+            _config=self._config,
+            _items=results,
+        )
 
     @property
     def choice(self):
-        return Items(self._context, [random.choice(self._strings)])
+        return Items(
+            _context=self._context,
+            _config=self._config,
+            _items=[random.choice(self._strings)],
+        )
 
     @property
     def lower(self):
-        return Items(self._context, [x.lower() for x in self._strings])
+        return Items(
+            _context=self._context,
+            _config=self._config,
+            _items=[x.lower() for x in self._strings],
+        )
 
     @property
     def capitalize(self):
-        return Items(self._context, [capitalize(x) for x in self._strings])
+        return Items(
+            _context=self._context,
+            _config=self._config,
+            _items=[capitalize(x) for x in self._strings],
+        )
 
     def __repr__(self):
         return self.__str__()
@@ -104,6 +127,7 @@ class Transform:
 @dataclass
 class Items(Transform):
     _context: Context
+    _config: "Config"
     _items: list[str]
 
     @property
@@ -125,10 +149,22 @@ class Items(Transform):
         return self.__str__()
 
 
+class Distribution:
+    STANDARD = 0
+    NORMAL = 1
+
+
+@dataclass
+class Config:
+    count: int = 1
+    distribution: Distribution = Distribution.STANDARD
+
+
 @dataclass
 class Text(Transform, All):
     name: str
     _context: Context
+    _config: Config
     _items: dict[frozenset, list[str]]
     _all: dict[str, "Text"] = field(default_factory=dict)
 
@@ -147,7 +183,11 @@ class Text(Transform, All):
         return result
 
     def groups(self, *args):
-        return Items(self._context, self._groups(*args))
+        return Items(
+            _context=self._context,
+            _config=self.config,
+            _items=self._groups(*args),
+        )
 
     def _groups_from_items(self):
         return frozenset(self._items.keys())
@@ -169,16 +209,25 @@ class Text(Transform, All):
             return list(self._items[_default])
 
     def set(self, name):
-        item = Items(self._context, [random.choice(self._strings)])
+        item = Items(
+            _context,
+            self._context,
+            _config=self._config,
+            _items=[random.choice(self._strings)],
+        )
         set_path(self.context, name, item)
         return item
 
+    @property
+    def count(self):
+        return self.draw(self._config.count)
+
     @property
     def items(self):
         return Items(self._context, self._strings)
 
     def __str__(self):
-        return self._context.fstr(random.choice(self._strings))
+        return str(self.count)
 
     def __repr__(self):
         return self.__str__()
@@ -195,7 +244,7 @@ def split_and_capitalize(string, split, join):
     return join.join([capitalize(x) for x in string.split(split)])
 
 
-def niceup_string(string):
+def niceup_name(string):
     string = split_and_capitalize(string, ".", " - ")
     string = split_and_capitalize(string, "_", " ")
     return string
@@ -207,7 +256,7 @@ def set_path(context, path, value, all=False):
     prefix = 0
     for x in parts[:-1]:
         if all and isinstance(value, Text):
-            cur._all[niceup_string(value.name[prefix:])] = value
+            cur._all[niceup_name(value.name[prefix:])] = value
             prefix += len(x) + 1
         if hasattr(cur, x):
             cur = getattr(cur, x)
@@ -217,13 +266,13 @@ def set_path(context, path, value, all=False):
             cur = new
     try:
         if all and isinstance(value, Text):
-            cur._all[niceup_string(value.name[prefix:])] = value
+            cur._all[niceup_name(value.name[prefix:])] = value
         if all:
-            value._all[niceup_string(value.name[prefix:])] = value
+            value._all[niceup_name(value.name[prefix:])] = value
     except AttributeError:
         print(path)
         raise
-    cur._all[niceup_string(value.name[prefix:])] = value
+    cur._all[niceup_name(value.name[prefix:])] = value
     setattr(cur, parts[-1], value)
 
 
@@ -234,13 +283,24 @@ def build_context():
     return context
 
 
+def build_config(avasar):
+    count = 1
+    if "count" in avasar:
+        count = avasar["count"]
+    return Config(count)
+
+
 def read_toml(context):
     map = defaultdict(lambda: defaultdict(list))
+    configs = dict()
     for file in _data.iterdir():
         if file.is_file() and file.name.endswith(".toml"):
             with open(file, "r", encoding="UTF-8") as f:
                 data = toml.load(f)
             for avasar in data["avasar"]:
+                name = avasar["name"]
+                if name not in configs:
+                    configs[name] = build_config(avasar)
                 groups = avasar.get("groups")
                 if not groups:
                     groups = []
@@ -253,7 +313,6 @@ def read_toml(context):
                 for i in range(len(groups)):
                     for x in combinations(groups, i + 1):
                         combs.add(frozenset(x))
-                name = avasar["name"]
                 if isinstance(name, list):
                     for comb in combs:
                         for x in name:
@@ -272,9 +331,19 @@ def read_toml(context):
             groups[key] = item
             if isinstance(key, frozenset) and len(key) == 1:
                 gr_name = list(key)[0]
-                group[gr_name] = Text(gr_name, context, {_default: item})
+                group[gr_name] = Text(
+                    name=name,
+                    _context=context,
+                    _config=configs[name],
+                    _items={_default: item},
+                )
         ns = Namespace()
         ns.__dict__ = group
-        obj = Text(name, context, groups)
+        obj = Text(
+            name=name,
+            _context=context,
+            _config=configs[name],
+            _items=groups,
+        )
         obj.group = ns
         set_path(context, name, obj, all=True)
