@@ -9,7 +9,7 @@ import sys
 
 def run():
     context = build_context()
-    context.__dict__["set_groups"] = context.set_groups
+    context.__dict__["set_groups"] = context._set_groups
     if len(sys.argv) > 1:
         if sys.argv[1] == "test":
             print(context.fstr("{gen.character}"))
